@@ -10,15 +10,15 @@ use Lingua::AR::Word::Stem;	#needed to find the stem
 use Lingua::AR::Word::Encode;	#needed to encode into ArabTeX
 
 
-our $VERSION = '1.5.2';
+our $VERSION = '1.5.3';
 
 
 sub new{
 
-	my $class=$_[0];
+	my $class=shift;
 
 	my $this={
-		_word=>$_[1],
+		_word=>shift,
 		_stem=>"",
 		_translation=>"",
 		_arabtex=>""
@@ -33,22 +33,19 @@ sub new{
 
 
 sub get_word{
-	"WORD: $_[0]->{_word}\n";
+	$_[0]->{_word};
 }
 
 sub get_stem{
-	"STEM: $_[0]->{_stem}\n";
-
+	$_[0]->{_stem};
 }
 
 sub get_arabtex{
-	"ARABTEX: $_[0]->{_arabtex}\n";
-
+	$_[0]->{_arabtex};
 }
 
 
 
-
 1;
 __END__
 
@@ -58,22 +55,19 @@ Lingua::AR::Word - Perl extension for getting the stem and ArabTeX encoding of A
 
 =head1 SYNOPSIS
 
-use utf8;
-use Lingua::AR::Word;
+	use utf8;
+	use Lingua::AR::Word;
 
+	my $word=Lingua::AR::Word->new(ARABIC_WORD_IN_UTF8);
 
-my $word=Lingua::AR::Word->new(ARABIC_WORD_IN_UTF8);
+	open FOUTPUT, ">>:utf8" TEST" or die "Cannot create TEST: $!\n";
+	
 
+	print FOUTPUT $word->get_word();
+	print FOUTPUT $word->get_stem();
+	print FOUTPUT $word->get_arabtex();
 
-open FOUTPUT, ">>TEST" or die "Cannot create TEST: $!\n";
-binmode(FOUTPUT,":utf8");
-
-print FOUTPUT $word->get_word();
-print FOUTPUT $word->get_stem();
-print FOUTPUT $word->get_arabtex();
-
-
-close FOUTPUT;
+	close FOUTPUT;
 
 
 =head1 DESCRIPTION
@@ -84,7 +78,7 @@ You will get the ArabTeX translittered form through get_arabtex().
 If you also want the translation, you'll need to create the $db object (described in the Lingua::AR::Db module), so that it may look for its meaning in the correct Database.
 
 Remember that input-output directly to shell will not be useful as long as your shell doesn't support utf8 encoded characters.
-In the example above, for example, I piped the output to another file AND I forced its writing in utf8.
+In the example above, for example, I piped the output to another file forcing its writing in utf8.
 
 
 
@@ -100,7 +94,7 @@ Andrea Benazzo, E<lt>andy@slacky.itE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005 Andrea Benazzo. All rights reserved.
+Copyright (c) 2006 Andrea Benazzo. All rights reserved.
  This program is free software; you can redistribute it and/or
  modify it under the same terms as Perl itself.
 
